# intentional-ai

[![PyPI - Version](https://img.shields.io/pypi/v/intentional-ai.svg)](https://pypi.org/project/intentional-ai)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/intentional-ai.svg)](https://pypi.org/project/intentional-ai)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install intentional-ai
```

## License

`intentional-ai` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
